
local editor = {}

function editor:init()
	-- Load resources
	self.cell = love.graphics.newImage("assets/cell.png")
	self.selection = love.graphics.newImage("assets/selection.png")

	self.selectionX, self.selectionY = 0, 0 

	-- Generate grid
	for x = 1, 16 do
		grid[x] = {}

		for y = 1, 16 do
			grid[x][y] = 0
		end
	end

	-- Create the canvas
	self.canvas = love.graphics.newCanvas(256, 256)
	self.canvas:setFilter("nearest", "nearest")
end

function editor:draw()
	-- Draw to the canvas instead of the screen
	love.graphics.setCanvas(self.canvas)

	-- Set the background
	love.graphics.clear(255, 128, 128)

	-- Draw the selection
	love.graphics.draw(self.selection, self.selectionX * 16 - 16,
		self.selectionY * 16 - 16)

	-- Draw the grid
	for x = 1, 16 do
		for y = 1, 16 do
			if grid[x][y] == 1 then
				love.graphics.draw(self.cell, x * 16 - 16, y * 16 - 16)
			end
		end
	end

	-- Draw the canvas to the screen
	love.graphics.setCanvas()
	love.graphics.draw(self.canvas, 0, 0, 0, scaleX, scaleY)
end

function editor:update()
	-- Calculate which cell is under the cursor
	self.selectionX =
		math.ceil(love.mouse.getX() / (love.graphics.getWidth() / 16))
	self.selectionY =
		math.ceil(love.mouse.getY() / (love.graphics.getHeight() / 16))
end

function editor:mousepressed(x, y, button)
	-- Toggle the state of the cell under the cursor
	if button == 1 then
		if grid[self.selectionX][self.selectionY] == 1 then
			grid[self.selectionX][self.selectionY] = 0
		else
			grid[self.selectionX][self.selectionY] = 1
		end
	end
end

function editor:keypressed(key)
	if key == "tab" then
		gamestate.push(update)
	end
end

return editor
