
local update = {}

local function getCell(x, y)
	if x > 0 and x < 17 and y > 0 and y < 17 then
		return grid[x][y]
	else
		return 0
	end
end

function update:init()
	-- Load the cell sprite
	self.cell = love.graphics.newImage("assets/cell.png")
	
	-- Set the default update interval
	self.interval = 1

	-- Initialize the counter
	self.counter = 0
	
	-- Create the canvas
	self.canvas = love.graphics.newCanvas(256, 256)
	self.canvas:setFilter("nearest", "nearest")
end

function update:draw()
	-- Draw to the canvas instead of the screen
	love.graphics.setCanvas(self.canvas)

	-- Set the background
	love.graphics.clear(255, 128, 128)

	-- Draw the grid
	for x = 1, 16 do
		for y = 1, 16 do
			if grid[x][y] == 1 then
				love.graphics.draw(self.cell, x * 16 - 16, y * 16 - 16)
			end
		end
	end
	
	-- Draw the canvas to the screen
	love.graphics.setCanvas()
	love.graphics.draw(self.canvas, 0, 0, 0, scaleX, scaleY)
end

function update:updateCells()
	for x = 1, 16 do
		for y = 1, 16 do
			local neighbours =
				getCell(x - 1, y - 1) +
				getCell(x, y - 1) +
				getCell(x + 1, y - 1) +
				getCell(x - 1, y) +
				getCell(x + 1, y) +
				getCell(x - 1, y + 1) +
				getCell(x, y + 1) +
				getCell(x + 1, y + 1)
			
			if grid[x][y] == 1 then
				if neighbours == 2 or neighbours == 3 then
					newgrid[x][y] = 1
				else
					newgrid[x][y] = 0
				end
			else
				if neighbours == 3 then
					newgrid[x][y] = 1
				else
					newgrid[x][y] = 0
				end
			end
		end
	end

	-- Swap tables
	grid, newgrid = newgrid, grid
end

function update:update(deltaTime)
	self.counter = self.counter + deltaTime

	if self.counter > self.interval then
		self.counter = self.counter - self.interval
		self:updateCells()
	end
end

function update:keypressed(key)
	if key == "tab" then
		gamestate.pop()
	end
end

function update:wheelmoved(x, y)
	if y > 0 then
		self.interval = self.interval / 1.5
	elseif y < 0 then
		self.interval = self.interval * 1.5
	end
end

return update

